@@ -54,9 +54,7 @@ def _get_kwargs(
         "url": f"/projects/{project_id}/locations/{location_id}/upload",
     }
 
-    _body = body.to_multipart()
-
-    _kwargs["files"] = _body
+    _kwargs["files"] = body.to_multipart()
 
     _kwargs["headers"] = headers
     return _kwargs
